// Author: Pete Kirkham
//
// quad store utils.
//
#ifndef _TRIPLE_WRITER_H_
#define _TRIPLE_WRITER_H_

#include "core/triple_target.h"
    
class triple_writer : public triple_target
{
public:
    triple_writer (std::ostream& out) : _out(out) { }
    ~triple_writer () { flush(); }

    virtual void add_triple (const char* subject,   size_t subject_length,   field_type subject_type,
                             const char* predicate, size_t predicate_length, // always an uri
                             const char* object,    size_t object_length,    field_type object_type,
                             const char* graph,     size_t graph_length)
    {
        if (graph && (_prev_graph != graph))
        {
            _out << "#graph " << graph << std::endl;
            _prev_graph = graph;
        }
        
        if (subject_type == type_uri)
        {
            _out << "<" << subject << "> <";
        }
        else
        {
            _out << "_:" << subject << " <";
        }

        _out << predicate;

        if (object_type == type_uri)
        {
            _out << "> <" << object << ">.";
        }
        else if (object_type == type_blank_node)
        {
            _out << "> _:" << object << ".";
        }
        else
        {
            _out << "> \"";
            write_turtle_encoded(_out, object);
            _out << "\".";
        }

        _out << std::endl;
    }
    
    void flush () 
    {
    }

private:
    std::string     _prev_graph;
    std::ostream&   _out;
};
#endif // _TRIPLE_WRITER_H_
